// 序号生成方式
export const snGenerationMethodList = [
  { value: 'recalculate', label: '重新计算' },
  { value: 'follow', label: '跟随上题' },
];

// 查看方式
export const viewMethodList = [
  { value: 'independent', label: '独立排放' },
  { value: 'list', label: '播放列表' },
];

// 音频查看方式
export const audioViewMethodList = [
  { value: 'independent', label: '独立' },
  { value: 'list', label: '列表' },
  { value: 'icon', label: '图标' },
];

// 序号类型
export const serialNumberTypeList = [
  { value: 'letter', label: '字母' },
  { value: 'number', label: '数字' },
  { value: 'capital', label: '大写字母' },
  { value: 'bracket_number', label: '括号数字' },
];

/**
 * 判断序号类型
 * @param {string} str
 */
export function checkString(str) {
  const number = /\d/.test(str); // 判断是否包含数字
  const letter = /[a-zA-Z]/.test(str); // 判断是否包含字母
  const capital = /[A-Z]/.test(str); // 判断是否包含大写字母
  const bracket_number = /\(\d+\)/.test(str); // 判断是否包含括号数字，例如 (123)
  return { number, letter, capital, bracket_number };
}

/**
 * 改变选项类型
 * @param {string} serial_number 序号
 */
export function switchSerialNumber(serial_number) {
  let sn_type = checkString(serial_number);
  let index = serialNumberTypeList.findIndex(({ value }) => value === sn_type);
  sn_type = serialNumberTypeList[index + 1]?.value || serialNumberTypeList[0].value;
}

// 计算选项方法
export const computeOptionMethods = {
  [serialNumberTypeList[0].value]: (i) => `${String.fromCharCode(97 + i)}.`,
  [serialNumberTypeList[1].value]: (i) => `${i + 1}.`,
  [serialNumberTypeList[2].value]: (i) => `${String.fromCharCode(65 + i)}.`,
  [serialNumberTypeList[3].value]: (i) => `(${i + 1})`,
};

/**
 * 计算选项序号
 * @param {Number} i 序号
 * @param {String} sn_type 选项类型
 * @returns String 题号
 */
export function computedSerialNumber(i, sn_type) {
  const computationMethod = computeOptionMethods[sn_type];
  if (computationMethod) {
    return computationMethod(i);
  }
  return '';
}
